@@ -12,6 +12,6 @@ dpkg -x "${deb_package}" "${install_dir}"
 
 # Return PATH var to parent shell
 package_dir="${install_dir}/usr/bin"
-echo "Run this if you want to use fresh builded hurl package:"
+echo "Run this if you want to use fresh built Hurl package:"
 echo "  export PATH=$package_dir:$PATH"
 
