@@ -10,6 +10,6 @@ mkdir -p "${install_dir}"
 tar xvf "${generic_linux_package}" -C "${install_dir}" --strip-components=1
 
 # Return PATH var to parent shell
-echo "Run this if you want to use fresh builded hurl package:"
+echo "Run this if you want to use fresh built Hurl package:"
 echo "  export PATH=${install_dir}:$PATH"
 
