@@ -12,8 +12,8 @@ hurlfmt --version
 
 # integration tests
 cd integration
+./hurlfmt_check.sh tests_ok/*.hurl tests_failed/*.hurl
 ./integration.py
 ./test_curl_commands.sh 
 ./test_html_output.py tests_ok/*.html tests_failed/*.html
-#./report.py TODO: review test report
 
