@@ -115,6 +115,7 @@ main() {
     arg="${1:-}"
     check_args "${arg}"
     updated_count=0
+    blacklisted="indexmap"
 
     # update toml
     for package in packages/*; do
@@ -133,6 +134,12 @@ main() {
             if [ "${newest_version}" == "${actual_version}" ]; then
                 echo "${color_green}newest${color_reset}"
             else
+                # Blacklist some crates
+                if [[ ${crate} =~ ${blacklisted} ]]; then
+                    echo "${color_yellow} blacklisted latest ${last_version}${color_reset}"
+                    continue
+                fi
+
                 if [ "${arg}" = "--check" ]; then
                     echo "${color_red}old, please update to latest ${last_version}${color_reset}"
                     updated_count=$((updated_count + 1))
