@@ -15,7 +15,6 @@
  * limitations under the License.
  *
  */
-use std::io::Read;
 use std::str;
 use std::str::FromStr;
 
@@ -102,7 +101,7 @@ impl Client {
                 }
             }
             request_spec = RequestSpec {
-                method: Method::Get,
+                method: Method("GET".to_string()),
                 url: redirect_url,
                 ..Default::default()
             };
@@ -150,6 +149,7 @@ impl Client {
             self.handle.ssl_key(client_key_file).unwrap();
             self.handle.ssl_cert_type("PEM").unwrap();
         }
+        self.handle.path_as_is(options.path_as_is).unwrap();
         if let Some(proxy) = options.proxy.clone() {
             self.handle.proxy(proxy.as_str()).unwrap();
         }
@@ -170,7 +170,7 @@ impl Client {
         self.set_cookies(&request_spec.cookies);
         self.set_form(&request_spec.form);
         self.set_multipart(&request_spec.multipart);
-        let mut request_spec_body: &[u8] = &request_spec.body.bytes();
+        let request_spec_body = &request_spec.body.bytes();
         self.set_body(request_spec_body);
         self.set_headers(request_spec, options);
 
@@ -191,16 +191,11 @@ impl Client {
         let mut request_body = Vec::<u8>::new();
         let mut response_body = Vec::<u8>::new();
 
-        if *method == Method::Head {
+        if *method == Method("HEAD".to_string()) {
             self.handle.nobody(true).unwrap();
         }
         {
             let mut transfer = self.handle.transfer();
-            if !request_spec_body.is_empty() {
-                transfer
-                    .read_function(|buf| Ok(request_spec_body.read(buf).unwrap_or(0)))
-                    .unwrap();
-            }
 
             transfer
                 .debug_function(|info_type, data| match info_type {
@@ -219,8 +214,8 @@ impl Client {
                         }
 
                         // If we don't send any data, we log headers and empty body here
-                        // instead of relying on libcurl computing body in easy::InfoType::DataOut.
-                        // because libcurl dont call easy::InfoType::DataOut if there is no data
+                        // instead of relying on libcurl computing body in `easy::InfoType::DataOut`.
+                        // because libcurl dont call `easy::InfoType::DataOut` if there is no data
                         // to send.
                         if !has_body_data && verbose {
                             let debug_request = Request {
@@ -235,15 +230,17 @@ impl Client {
                             logger.info(">");
 
                             if very_verbose {
-                                debug_request.log_body(logger);
+                                debug_request.log_body(true, logger);
                             }
                         }
                     }
                     // We use this callback to get the real body bytes sent by libcurl.
                     easy::InfoType::DataOut => {
-                        // Extracts request body from libcurl debug info.
-                        request_body.extend(data);
-                        if verbose {
+                        // We log request headers with `easy::InfoType::DataOut` using libcurl
+                        // debug functions: there is no libcurl function to get the request headers.
+                        // As we can be called multiple times in this callback, we only log headers the
+                        // first time we send data (marked when the request body is empty).
+                        if verbose && request_body.is_empty() {
                             let debug_request = Request {
                                 url: url.to_string(),
                                 method: method.to_string(),
@@ -256,9 +253,12 @@ impl Client {
                             logger.info(">");
 
                             if very_verbose {
-                                debug_request.log_body(logger);
+                                debug_request.log_body(true, logger);
                             }
                         }
+
+                        // Extracts request body from libcurl debug info.
+                        request_body.extend(data);
                     }
                     // Curl debug logs
                     easy::InfoType::Text => {
@@ -369,7 +369,9 @@ impl Client {
             }
             logger.info("<");
             if very_verbose {
-                response.log_body(logger);
+                response.log_body(true, logger);
+                logger.debug("");
+                timings.log(logger);
             }
         }
 
@@ -506,7 +508,7 @@ impl Client {
     fn set_body(&mut self, data: &[u8]) {
         if !data.is_empty() {
             self.handle.post(true).unwrap();
-            self.handle.post_field_size(data.len() as u64).unwrap();
+            self.handle.post_fields_copy(data).unwrap();
         }
     }
 
