@@ -15,6 +15,7 @@
  * limitations under the License.
  *
  */
+use hurl_core::ast::Retry;
 use std::time::Duration;
 
 #[derive(Debug, Clone)]
@@ -30,9 +31,10 @@ pub struct ClientOptions {
     pub insecure: bool,
     pub max_redirect: Option<usize>,
     pub no_proxy: Option<String>,
+    pub path_as_is: bool,
     pub proxy: Option<String>,
     pub resolves: Vec<String>,
-    pub retry_max_count: Option<usize>,
+    pub retry: Retry,
     pub ssl_no_revoke: bool,
     pub timeout: Duration,
     pub user: Option<String>,
@@ -60,9 +62,10 @@ impl Default for ClientOptions {
             insecure: false,
             max_redirect: Some(50),
             no_proxy: None,
+            path_as_is: false,
             proxy: None,
             resolves: vec![],
-            retry_max_count: Some(10),
+            retry: Retry::None,
             ssl_no_revoke: false,
             timeout: Duration::from_secs(300),
             user: None,
@@ -118,6 +121,9 @@ impl ClientOptions {
             arguments.push("--max-redirs".to_string());
             arguments.push(max_redirect.to_string());
         }
+        if self.path_as_is {
+            arguments.push("--path-as-is".to_string());
+        }
         if let Some(ref proxy) = self.proxy {
             arguments.push("--proxy".to_string());
             arguments.push(format!("'{proxy}'"));
@@ -159,6 +165,7 @@ mod tests {
                 follow_location: true,
                 max_redirect: Some(10),
                 cookie_input_file: Some("cookie_file".to_string()),
+                path_as_is: true,
                 proxy: Some("localhost:3128".to_string()),
                 no_proxy: None,
                 verbosity: None,
@@ -167,7 +174,7 @@ mod tests {
                     "foo.com:80:192.168.0.1".to_string(),
                     "bar.com:443:127.0.0.1".to_string()
                 ],
-                retry_max_count: Some(10),
+                retry: Retry::None,
                 ssl_no_revoke: false,
                 timeout: Duration::from_secs(10),
                 connect_timeout: Duration::from_secs(20),
@@ -188,6 +195,7 @@ mod tests {
                 "--location".to_string(),
                 "--max-redirs".to_string(),
                 "10".to_string(),
+                "--path-as-is".to_string(),
                 "--proxy".to_string(),
                 "'localhost:3128'".to_string(),
                 "--resolve".to_string(),
