@@ -17,10 +17,12 @@
  */
 
 //! HTML report
-
-mod file;
+mod nav;
 mod report;
+mod run;
+mod source;
 mod testcase;
+mod timeline;
 
 pub use report::write_report;
 pub use testcase::Testcase;
