@@ -15,12 +15,12 @@
  * limitations under the License.
  *
  */
-
-use crate::cli;
-use crate::runner::HurlResult;
-
+use indexmap::map::IndexMap;
 use xmltree::{Element, XMLNode};
 
+use crate::runner::HurlResult;
+use crate::util::logger;
+
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct Testcase {
     id: String,
@@ -31,16 +31,16 @@ pub struct Testcase {
 }
 
 impl Testcase {
-    /// Creates an XML Junit <testcase> from an Hurl result.
-    pub fn from_hurl_result(hurl_result: &HurlResult, content: &str) -> Testcase {
-        let id = hurl_result.filename.clone();
-        let name = hurl_result.filename.clone();
+    /// Creates an XML Junit &lt;testcase&gt; from an [`HurlResult`].
+    pub fn from(hurl_result: &HurlResult, content: &str, filename: &str) -> Testcase {
+        let id = filename.to_string();
+        let name = filename.to_string();
         let time_in_ms = hurl_result.time_in_ms;
         let mut failures = vec![];
         let mut errors = vec![];
 
         for error in hurl_result.errors() {
-            let message = cli::error_string_no_color(&hurl_result.filename, content, error);
+            let message = logger::error_string(filename, content, error, false);
             if error.assert {
                 failures.push(message);
             } else {
@@ -59,7 +59,7 @@ impl Testcase {
     /// Serializes this testcase to XML.
     pub fn to_xml(&self) -> Element {
         let name = "testcase".to_string();
-        let mut attributes = indexmap::map::IndexMap::new();
+        let mut attributes = IndexMap::new();
         attributes.insert("id".to_string(), self.id.clone());
         attributes.insert("name".to_string(), self.name.clone());
         let time_in_seconds = format!("{:.3}", self.time_in_ms as f64 / 1000.0);
@@ -72,7 +72,7 @@ impl Testcase {
                 namespace: None,
                 namespaces: None,
                 name: "failure".to_string(),
-                attributes: indexmap::map::IndexMap::new(),
+                attributes: IndexMap::new(),
                 children: vec![XMLNode::Text(message)],
             };
             children.push(XMLNode::Element(element));
@@ -83,7 +83,7 @@ impl Testcase {
                 namespace: None,
                 namespaces: None,
                 name: "error".to_string(),
-                attributes: indexmap::map::IndexMap::new(),
+                attributes: IndexMap::new(),
                 children: vec![XMLNode::Text(message)],
             };
             children.push(XMLNode::Element(element));
@@ -97,18 +97,26 @@ impl Testcase {
             children,
         }
     }
+
+    pub fn get_error_count(&self) -> usize {
+        self.errors.len()
+    }
+
+    pub fn get_fail_count(&self) -> usize {
+        self.failures.len()
+    }
 }
 
 #[cfg(test)]
 mod test {
+    use hurl_core::ast::SourceInfo;
+
     use crate::report::junit::testcase::Testcase;
     use crate::runner::{EntryResult, Error, HurlResult, RunnerError};
-    use hurl_core::ast::SourceInfo;
 
     #[test]
     fn test_create_testcase_success() {
         let hurl_result = HurlResult {
-            filename: "test.hurl".to_string(),
             entries: vec![],
             time_in_ms: 230,
             success: true,
@@ -117,7 +125,8 @@ mod test {
 
         let mut buffer = Vec::new();
         let content = "";
-        Testcase::from_hurl_result(&hurl_result, content)
+        let filename = "test.hurl";
+        Testcase::from(&hurl_result, content, filename)
             .to_xml()
             .write(&mut buffer)
             .unwrap();
@@ -132,8 +141,8 @@ mod test {
         let content = r#"GET http://localhost:8000/not_found
 HTTP/1.0 200
 "#;
+        let filename = "test.hurl";
         let hurl_result = HurlResult {
-            filename: "test.hurl".to_string(),
             entries: vec![EntryResult {
                 entry_index: 1,
                 calls: vec![],
@@ -154,7 +163,7 @@ HTTP/1.0 200
             cookies: vec![],
         };
         let mut buffer = Vec::new();
-        Testcase::from_hurl_result(&hurl_result, content)
+        Testcase::from(&hurl_result, content, filename)
             .to_xml()
             .write(&mut buffer)
             .unwrap();
@@ -172,8 +181,8 @@ HTTP/1.0 200
     #[test]
     fn test_create_testcase_error() {
         let content = "GET http://unknown";
+        let filename = "test.hurl";
         let hurl_result = HurlResult {
-            filename: "test.hurl".to_string(),
             entries: vec![EntryResult {
                 entry_index: 1,
                 calls: vec![],
@@ -195,7 +204,7 @@ HTTP/1.0 200
             cookies: vec![],
         };
         let mut buffer = Vec::new();
-        Testcase::from_hurl_result(&hurl_result, content)
+        Testcase::from(&hurl_result, content, filename)
             .to_xml()
             .write(&mut buffer)
             .unwrap();
