@@ -22,12 +22,6 @@ use hurl_core::ast::SourceInfo;
 use crate::http::{Call, Cookie};
 use crate::runner::value::Value;
 
-#[derive(Clone, Debug, PartialEq, Eq)]
-pub enum Verbosity {
-    Verbose,
-    VeryVerbose,
-}
-
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct HurlResult {
     pub entries: Vec<EntryResult>,
@@ -187,6 +181,7 @@ pub enum RunnerError {
     },
 
     UnrenderableVariable {
+        name: String,
         value: String,
     },
 
@@ -198,4 +193,6 @@ pub enum RunnerError {
     FilterMissingInput {},
     FilterInvalidInput(String),
     FilterRegexNoCapture {},
+    FilterInvalidEncoding(String),
+    FilterDecode(String),
 }
