@@ -28,7 +28,7 @@ use crate::runner::response::{eval_asserts, eval_captures, eval_version_status_a
 use crate::runner::runner_options::RunnerOptions;
 use crate::runner::template::eval_template;
 use crate::runner::value::Value;
-use crate::util::logger::Logger;
+use crate::util::logger::{Logger, Verbosity};
 
 /// Runs an `entry` with `http_client` and returns one [`EntryResult`].
 ///
@@ -58,7 +58,7 @@ pub fn run(
             };
         }
     };
-    let client_options = http::ClientOptions::from(runner_options);
+    let client_options = ClientOptions::from(runner_options, logger.verbosity);
 
     // Experimental features with cookie storage
     use std::str::FromStr;
@@ -217,8 +217,8 @@ fn asserts_to_errors(asserts: &[AssertResult]) -> Vec<Error> {
         .collect()
 }
 
-impl From<&RunnerOptions> for ClientOptions {
-    fn from(runner_options: &RunnerOptions) -> Self {
+impl ClientOptions {
+    fn from(runner_options: &RunnerOptions, verbosity: Option<Verbosity>) -> Self {
         ClientOptions {
             cacert_file: runner_options.cacert_file.clone(),
             client_cert_file: runner_options.client_cert_file.clone(),
@@ -227,15 +227,17 @@ impl From<&RunnerOptions> for ClientOptions {
             follow_location: runner_options.follow_location,
             max_redirect: runner_options.max_redirect,
             cookie_input_file: runner_options.cookie_input_file.clone(),
+            path_as_is: runner_options.path_as_is,
             proxy: runner_options.proxy.clone(),
             no_proxy: runner_options.no_proxy.clone(),
-            verbosity: runner_options.verbosity.as_ref().map(|v| match v {
-                Verbosity::Verbose => http::Verbosity::Verbose,
-                Verbosity::VeryVerbose => http::Verbosity::VeryVerbose,
-            }),
+            verbosity: match verbosity {
+                Some(Verbosity::Verbose) => Some(http::Verbosity::Verbose),
+                Some(Verbosity::VeryVerbose) => Some(http::Verbosity::VeryVerbose),
+                _ => None,
+            },
             insecure: runner_options.insecure,
             resolves: runner_options.resolves.clone(),
-            retry_max_count: runner_options.retry_max_count,
+            retry: runner_options.retry,
             ssl_no_revoke: runner_options.ssl_no_revoke,
             timeout: runner_options.timeout,
             connect_timeout: runner_options.connect_timeout,
@@ -333,6 +335,14 @@ pub fn get_entry_options(
                         runner_options.max_redirect = Some(option.value);
                         logger.debug(format!("max-redirs: {}", option.value).as_str());
                     }
+                    EntryOption::PathAsIs(option) => {
+                        runner_options.path_as_is = option.value;
+                        logger.debug(format!("path-as-is: {}", option.value).as_str());
+                    }
+                    EntryOption::Proxy(option) => {
+                        runner_options.proxy = Some(option.value.clone());
+                        logger.debug(format!("proxy: {}", option.value).as_str());
+                    }
                     EntryOption::Retry(option) => {
                         runner_options.retry = option.value;
                         logger.debug(format!("retry: {}", option.value).as_str());
@@ -341,10 +351,6 @@ pub fn get_entry_options(
                         runner_options.retry_interval = Duration::from_millis(option.value);
                         logger.debug(format!("retry-interval: {}", option.value).as_str());
                     }
-                    EntryOption::RetryMaxCount(option) => {
-                        runner_options.retry_max_count = Some(option.value);
-                        logger.debug(format!("retry-max-count: {}", option.value).as_str());
-                    }
                     EntryOption::Variable(VariableOption {
                         value: VariableDefinition { name, value, .. },
                         ..
@@ -353,20 +359,10 @@ pub fn get_entry_options(
                         variables.insert(name.clone(), value);
                     }
                     EntryOption::Verbose(option) => {
-                        runner_options.verbosity = if option.value {
-                            Some(Verbosity::Verbose)
-                        } else {
-                            None
-                        };
                         logger.debug(format!("verbose: {}", option.value).as_str());
                     }
 
                     EntryOption::VeryVerbose(option) => {
-                        runner_options.verbosity = if option.value {
-                            Some(Verbosity::VeryVerbose)
-                        } else {
-                            None
-                        };
                         logger.debug(format!("very-verbose: {}", option.value).as_str());
                     }
                 }
@@ -403,7 +399,7 @@ fn has_options(entry: &Entry) -> bool {
 
 /// Returns the overridden `entry` verbosity, or the default `verbosity` file.
 pub fn get_entry_verbosity(entry: &Entry, verbosity: &Option<Verbosity>) -> Option<Verbosity> {
-    let mut verbosity = verbosity.clone();
+    let mut verbosity = *verbosity;
 
     for section in &entry.request.sections {
         if let SectionValue::Options(options) = &section.value {
