@@ -18,12 +18,15 @@
 use std::collections::HashMap;
 
 use chrono::{NaiveDateTime, Utc};
+use encoding;
+use encoding::DecoderTrap;
 use hurl_core::ast::{Filter, FilterValue, RegexValue, SourceInfo, Template};
 use percent_encoding::AsciiSet;
 
 use crate::html;
 use crate::runner::regex::eval_regex_value;
 use crate::runner::template::eval_template;
+use crate::runner::xpath;
 use crate::runner::{Error, RunnerError, Value};
 
 /// Apply successive `filters` to an input `value`.
@@ -33,10 +36,18 @@ pub fn eval_filters(
     value: &Value,
     variables: &HashMap<String, Value>,
     in_assert: bool,
-) -> Result<Value, Error> {
-    let mut value = value.clone();
+) -> Result<Option<Value>, Error> {
+    let mut value = Some(value.clone());
     for filter in filters {
-        value = eval_filter(filter, &value, variables, in_assert)?;
+        value = if let Some(value) = value {
+            eval_filter(filter, &value, variables, in_assert)?
+        } else {
+            return Err(Error {
+                source_info: filter.source_info.clone(),
+                inner: RunnerError::FilterMissingInput {},
+                assert: in_assert,
+            });
+        }
     }
     Ok(value)
 }
@@ -46,11 +57,14 @@ fn eval_filter(
     value: &Value,
     variables: &HashMap<String, Value>,
     in_assert: bool,
-) -> Result<Value, Error> {
+) -> Result<Option<Value>, Error> {
     match &filter.value {
         FilterValue::Count => eval_count(value, &filter.source_info, in_assert),
         FilterValue::DaysAfterNow => eval_days_after_now(value, &filter.source_info, in_assert),
         FilterValue::DaysBeforeNow => eval_days_before_now(value, &filter.source_info, in_assert),
+        FilterValue::Decode { encoding, .. } => {
+            eval_decode(value, encoding, variables, &filter.source_info, in_assert)
+        }
         FilterValue::Format { fmt, .. } => {
             eval_format(value, fmt, variables, &filter.source_info, in_assert)
         }
@@ -87,6 +101,9 @@ fn eval_filter(
         FilterValue::ToInt => eval_to_int(value, &filter.source_info, in_assert),
         FilterValue::UrlDecode => eval_url_decode(value, &filter.source_info, in_assert),
         FilterValue::UrlEncode => eval_url_encode(value, &filter.source_info, in_assert),
+        FilterValue::XPath { expr, .. } => {
+            eval_xpath(value, expr, variables, &filter.source_info, in_assert)
+        }
     }
 }
 
@@ -96,23 +113,15 @@ fn eval_regex(
     variables: &HashMap<String, Value>,
     source_info: &SourceInfo,
     assert: bool,
-) -> Result<Value, Error> {
+) -> Result<Option<Value>, Error> {
     let re = eval_regex_value(regex_value, variables)?;
     match value {
         Value::String(s) => match re.captures(s.as_str()) {
             Some(captures) => match captures.get(1) {
-                Some(v) => Ok(Value::String(v.as_str().to_string())),
-                None => Err(Error {
-                    source_info: source_info.clone(),
-                    inner: RunnerError::FilterRegexNoCapture {},
-                    assert,
-                }),
+                Some(v) => Ok(Some(Value::String(v.as_str().to_string()))),
+                None => Ok(None),
             },
-            None => Err(Error {
-                source_info: source_info.clone(),
-                inner: RunnerError::FilterRegexNoCapture {},
-                assert,
-            }),
+            None => Ok(None),
         },
         v => Err(Error {
             source_info: source_info.clone(),
@@ -122,11 +131,15 @@ fn eval_regex(
     }
 }
 
-fn eval_count(value: &Value, source_info: &SourceInfo, assert: bool) -> Result<Value, Error> {
+fn eval_count(
+    value: &Value,
+    source_info: &SourceInfo,
+    assert: bool,
+) -> Result<Option<Value>, Error> {
     match value {
-        Value::List(values) => Ok(Value::Integer(values.len() as i64)),
-        Value::Bytes(values) => Ok(Value::Integer(values.len() as i64)),
-        Value::Nodeset(size) => Ok(Value::Integer(*size as i64)),
+        Value::List(values) => Ok(Some(Value::Integer(values.len() as i64))),
+        Value::Bytes(values) => Ok(Some(Value::Integer(values.len() as i64))),
+        Value::Nodeset(size) => Ok(Some(Value::Integer(*size as i64))),
         v => Err(Error {
             source_info: source_info.clone(),
             inner: RunnerError::FilterInvalidInput(v._type()),
@@ -139,11 +152,11 @@ fn eval_days_after_now(
     value: &Value,
     source_info: &SourceInfo,
     assert: bool,
-) -> Result<Value, Error> {
+) -> Result<Option<Value>, Error> {
     match value {
         Value::Date(value) => {
             let diff = value.signed_duration_since(Utc::now());
-            Ok(Value::Integer(diff.num_days()))
+            Ok(Some(Value::Integer(diff.num_days())))
         }
         v => Err(Error {
             source_info: source_info.clone(),
@@ -157,11 +170,45 @@ fn eval_days_before_now(
     value: &Value,
     source_info: &SourceInfo,
     assert: bool,
-) -> Result<Value, Error> {
+) -> Result<Option<Value>, Error> {
     match value {
         Value::Date(value) => {
             let diff = Utc::now().signed_duration_since(*value);
-            Ok(Value::Integer(diff.num_days()))
+            Ok(Some(Value::Integer(diff.num_days())))
+        }
+        v => Err(Error {
+            source_info: source_info.clone(),
+            inner: RunnerError::FilterInvalidInput(v._type()),
+            assert,
+        }),
+    }
+}
+
+fn eval_decode(
+    value: &Value,
+    encoding_value: &Template,
+    variables: &HashMap<String, Value>,
+    source_info: &SourceInfo,
+    assert: bool,
+) -> Result<Option<Value>, Error> {
+    let encoding_value = eval_template(encoding_value, variables)?;
+    match value {
+        Value::Bytes(value) => {
+            match encoding::label::encoding_from_whatwg_label(encoding_value.as_str()) {
+                None => Err(Error {
+                    source_info: source_info.clone(),
+                    inner: RunnerError::FilterInvalidEncoding(encoding_value),
+                    assert,
+                }),
+                Some(enc) => match enc.decode(value, DecoderTrap::Strict) {
+                    Ok(decoded) => Ok(Some(Value::String(decoded))),
+                    Err(_) => Err(Error {
+                        source_info: source_info.clone(),
+                        inner: RunnerError::FilterDecode(encoding_value),
+                        assert,
+                    }),
+                },
+            }
         }
         v => Err(Error {
             source_info: source_info.clone(),
@@ -177,13 +224,13 @@ fn eval_format(
     variables: &HashMap<String, Value>,
     source_info: &SourceInfo,
     assert: bool,
-) -> Result<Value, Error> {
+) -> Result<Option<Value>, Error> {
     let fmt = eval_template(fmt, variables)?;
 
     match value {
         Value::Date(value) => {
             let formatted = format!("{}", value.format(fmt.as_str()));
-            Ok(Value::String(formatted))
+            Ok(Some(Value::String(formatted)))
         }
         v => Err(Error {
             source_info: source_info.clone(),
@@ -195,7 +242,11 @@ fn eval_format(
 
 // does not encode "/"
 // like Jinja template (https://jinja.palletsprojects.com/en/3.1.x/templates/#jinja-filters.urlencode)
-fn eval_url_encode(value: &Value, source_info: &SourceInfo, assert: bool) -> Result<Value, Error> {
+fn eval_url_encode(
+    value: &Value,
+    source_info: &SourceInfo,
+    assert: bool,
+) -> Result<Option<Value>, Error> {
     match value {
         Value::String(value) => {
             const FRAGMENT: &AsciiSet = &percent_encoding::NON_ALPHANUMERIC
@@ -205,7 +256,7 @@ fn eval_url_encode(value: &Value, source_info: &SourceInfo, assert: bool) -> Res
                 .remove(b'~')
                 .remove(b'/');
             let encoded = percent_encoding::percent_encode(value.as_bytes(), FRAGMENT).to_string();
-            Ok(Value::String(encoded))
+            Ok(Some(Value::String(encoded)))
         }
         v => Err(Error {
             source_info: source_info.clone(),
@@ -215,11 +266,15 @@ fn eval_url_encode(value: &Value, source_info: &SourceInfo, assert: bool) -> Res
     }
 }
 
-fn eval_url_decode(value: &Value, source_info: &SourceInfo, assert: bool) -> Result<Value, Error> {
+fn eval_url_decode(
+    value: &Value,
+    source_info: &SourceInfo,
+    assert: bool,
+) -> Result<Option<Value>, Error> {
     match value {
         Value::String(value) => {
             match percent_encoding::percent_decode(value.as_bytes()).decode_utf8() {
-                Ok(decoded) => Ok(Value::String(decoded.to_string())),
+                Ok(decoded) => Ok(Some(Value::String(decoded.to_string()))),
                 Err(_) => Err(Error {
                     source_info: source_info.clone(),
                     inner: RunnerError::FilterInvalidInput("Invalid UTF8 stream".to_string()),
@@ -235,7 +290,12 @@ fn eval_url_decode(value: &Value, source_info: &SourceInfo, assert: bool) -> Res
     }
 }
 
-fn eval_nth(value: &Value, source_info: &SourceInfo, assert: bool, n: u64) -> Result<Value, Error> {
+fn eval_nth(
+    value: &Value,
+    source_info: &SourceInfo,
+    assert: bool,
+    n: u64,
+) -> Result<Option<Value>, Error> {
     match value {
         Value::List(values) => match values.get(n as usize) {
             None => Err(Error {
@@ -246,7 +306,7 @@ fn eval_nth(value: &Value, source_info: &SourceInfo, assert: bool, n: u64) -> Re
                 )),
                 assert,
             }),
-            Some(value) => Ok(value.clone()),
+            Some(value) => Ok(Some(value.clone())),
         },
         v => Err(Error {
             source_info: source_info.clone(),
@@ -256,11 +316,15 @@ fn eval_nth(value: &Value, source_info: &SourceInfo, assert: bool, n: u64) -> Re
     }
 }
 
-fn eval_html_escape(value: &Value, source_info: &SourceInfo, assert: bool) -> Result<Value, Error> {
+fn eval_html_escape(
+    value: &Value,
+    source_info: &SourceInfo,
+    assert: bool,
+) -> Result<Option<Value>, Error> {
     match value {
         Value::String(value) => {
             let encoded = html::html_escape(value);
-            Ok(Value::String(encoded))
+            Ok(Some(Value::String(encoded)))
         }
         v => Err(Error {
             source_info: source_info.clone(),
@@ -274,11 +338,11 @@ fn eval_html_unescape(
     value: &Value,
     source_info: &SourceInfo,
     assert: bool,
-) -> Result<Value, Error> {
+) -> Result<Option<Value>, Error> {
     match value {
         Value::String(value) => {
             let decoded = html::html_unescape(value);
-            Ok(Value::String(decoded))
+            Ok(Some(Value::String(decoded)))
         }
         v => Err(Error {
             source_info: source_info.clone(),
@@ -295,13 +359,13 @@ fn eval_replace(
     assert: bool,
     old_value: &RegexValue,
     new_value: &Template,
-) -> Result<Value, Error> {
+) -> Result<Option<Value>, Error> {
     match value {
         Value::String(v) => {
             let re = eval_regex_value(old_value, variables)?;
             let new_value = eval_template(new_value, variables)?;
             let s = re.replace_all(v, new_value).to_string();
-            Ok(Value::String(s))
+            Ok(Some(Value::String(s)))
         }
         v => Err(Error {
             source_info: source_info.clone(),
@@ -317,7 +381,7 @@ fn eval_split(
     source_info: &SourceInfo,
     assert: bool,
     sep: &Template,
-) -> Result<Value, Error> {
+) -> Result<Option<Value>, Error> {
     match value {
         Value::String(s) => {
             let sep = eval_template(sep, variables)?;
@@ -325,7 +389,7 @@ fn eval_split(
                 .split(&sep)
                 .map(|v| Value::String(v.to_string()))
                 .collect();
-            Ok(Value::List(values))
+            Ok(Some(Value::List(values)))
         }
         v => Err(Error {
             source_info: source_info.clone(),
@@ -341,12 +405,14 @@ fn eval_to_date(
     variables: &HashMap<String, Value>,
     source_info: &SourceInfo,
     assert: bool,
-) -> Result<Value, Error> {
+) -> Result<Option<Value>, Error> {
     let fmt = eval_template(fmt, variables)?;
 
     match value {
         Value::String(v) => match NaiveDateTime::parse_from_str(v, fmt.as_str()) {
-            Ok(v) => Ok(Value::Date(v.and_local_timezone(chrono::Utc).unwrap())),
+            Ok(v) => Ok(Some(Value::Date(
+                v.and_local_timezone(chrono::Utc).unwrap(),
+            ))),
             Err(_) => Err(Error {
                 source_info: source_info.clone(),
                 inner: RunnerError::FilterInvalidInput(value.display()),
@@ -361,12 +427,16 @@ fn eval_to_date(
     }
 }
 
-fn eval_to_int(value: &Value, source_info: &SourceInfo, assert: bool) -> Result<Value, Error> {
+fn eval_to_int(
+    value: &Value,
+    source_info: &SourceInfo,
+    assert: bool,
+) -> Result<Option<Value>, Error> {
     match value {
-        Value::Integer(v) => Ok(Value::Integer(*v)),
-        Value::Float(v) => Ok(Value::Integer(*v as i64)),
+        Value::Integer(v) => Ok(Some(Value::Integer(*v))),
+        Value::Float(v) => Ok(Some(Value::Integer(*v as i64))),
         Value::String(v) => match v.parse::<i64>() {
-            Ok(i) => Ok(Value::Integer(i)),
+            Ok(i) => Ok(Some(Value::Integer(i))),
             Err(_) => Err(Error {
                 source_info: source_info.clone(),
                 inner: RunnerError::FilterInvalidInput(value.display()),
@@ -381,6 +451,63 @@ fn eval_to_int(value: &Value, source_info: &SourceInfo, assert: bool) -> Result<
     }
 }
 
+pub fn eval_xpath(
+    value: &Value,
+    expr: &Template,
+    variables: &HashMap<String, Value>,
+    source_info: &SourceInfo,
+    assert: bool,
+) -> Result<Option<Value>, Error> {
+    match value {
+        Value::String(xml) => {
+            // The filter will use the HTML parser that should also work with XML input
+            let is_html = true;
+            eval_xpath_string(xml, expr, variables, source_info, is_html)
+        }
+        v => Err(Error {
+            source_info: source_info.clone(),
+            inner: RunnerError::FilterInvalidInput(v._type()),
+            assert,
+        }),
+    }
+}
+
+pub fn eval_xpath_string(
+    xml: &str,
+    expr_template: &Template,
+    variables: &HashMap<String, Value>,
+    source_info: &SourceInfo,
+    is_html: bool,
+) -> Result<Option<Value>, Error> {
+    let expr = eval_template(expr_template, variables)?;
+    let result = if is_html {
+        xpath::eval_html(xml, &expr)
+    } else {
+        xpath::eval_xml(xml, &expr)
+    };
+    match result {
+        Ok(value) => Ok(Some(value)),
+        Err(xpath::XpathError::InvalidXml {}) => Err(Error {
+            source_info: source_info.clone(),
+            inner: RunnerError::QueryInvalidXml,
+            assert: false,
+        }),
+        Err(xpath::XpathError::InvalidHtml {}) => Err(Error {
+            source_info: source_info.clone(),
+            inner: RunnerError::QueryInvalidXml,
+            assert: false,
+        }),
+        Err(xpath::XpathError::Eval {}) => Err(Error {
+            source_info: expr_template.source_info.clone(),
+            inner: RunnerError::QueryInvalidXpathEval,
+            assert: false,
+        }),
+        Err(xpath::XpathError::Unsupported {}) => {
+            panic!("Unsupported xpath {expr}"); // good usecase for panic - I could not reproqduce this usecase myself
+        }
+    }
+}
+
 #[cfg(test)]
 pub mod tests {
     use chrono::offset::Utc;
@@ -412,6 +539,7 @@ pub mod tests {
                 &variables,
                 false,
             )
+            .unwrap()
             .unwrap(),
             Value::Integer(3)
         );
@@ -432,6 +560,7 @@ pub mod tests {
                 &variables,
                 false,
             )
+            .unwrap()
             .unwrap(),
             Value::Integer(3)
         );
@@ -461,6 +590,7 @@ pub mod tests {
                 &variables,
                 false,
             )
+            .unwrap()
             .unwrap(),
             Value::Integer(0)
         );
@@ -476,6 +606,7 @@ pub mod tests {
                 &variables,
                 false,
             )
+            .unwrap()
             .unwrap(),
             Value::Integer(1)
         );
@@ -489,6 +620,7 @@ pub mod tests {
                 &variables,
                 false,
             )
+            .unwrap()
             .unwrap(),
             Value::Integer(-1)
         );
@@ -525,6 +657,7 @@ pub mod tests {
                 &variables,
                 false,
             )
+            .unwrap()
             .unwrap(),
             Value::String("02/04/2017 12:50".to_string())
         );
@@ -559,6 +692,7 @@ pub mod tests {
                 &variables,
                 false,
             )
+            .unwrap()
             .unwrap(),
             Value::String("Bob".to_string())
         );
@@ -620,6 +754,7 @@ pub mod tests {
                 &variables,
                 false,
             )
+            .unwrap()
             .unwrap(),
             Value::String(
                 "https%3A//mozilla.org/%3Fx%3D%D1%88%D0%B5%D0%BB%D0%BB%D1%8B".to_string()
@@ -641,6 +776,7 @@ pub mod tests {
                 &variables,
                 false,
             )
+            .unwrap()
             .unwrap(),
             Value::String("https://mozilla.org/?x=шеллы".to_string())
         );
@@ -660,15 +796,20 @@ pub mod tests {
                 &variables,
                 false
             )
+            .unwrap()
             .unwrap(),
             Value::Integer(123)
         );
         assert_eq!(
-            eval_filter(&filter, &Value::Integer(123), &variables, false).unwrap(),
+            eval_filter(&filter, &Value::Integer(123), &variables, false)
+                .unwrap()
+                .unwrap(),
             Value::Integer(123)
         );
         assert_eq!(
-            eval_filter(&filter, &Value::Float(1.6), &variables, false).unwrap(),
+            eval_filter(&filter, &Value::Float(1.6), &variables, false)
+                .unwrap()
+                .unwrap(),
             Value::Integer(1)
         );
     }
@@ -726,6 +867,7 @@ pub mod tests {
                     &variables,
                     false
                 )
+                .unwrap()
                 .unwrap(),
                 Value::String(output.to_string())
             );
@@ -757,6 +899,7 @@ pub mod tests {
                     &variables,
                     false
                 )
+                .unwrap()
                 .unwrap(),
                 Value::String(output.to_string())
             );
@@ -789,6 +932,7 @@ pub mod tests {
                 &variables,
                 false
             )
+            .unwrap()
             .unwrap(),
             Value::Integer(2)
         );
@@ -849,6 +993,7 @@ pub mod tests {
                 &variables,
                 false
             )
+            .unwrap()
             .unwrap(),
             Value::String("1,2,3,4".to_string())
         );
@@ -882,6 +1027,7 @@ pub mod tests {
                 &variables,
                 false
             )
+            .unwrap()
             .unwrap(),
             Value::List(vec![
                 Value::String("1".to_string()),
@@ -925,6 +1071,7 @@ pub mod tests {
                 &variables,
                 false
             )
+            .unwrap()
             .unwrap(),
             Value::Date(datetime_utc)
         );
@@ -959,6 +1106,7 @@ pub mod tests {
                 &variables,
                 false
             )
+            .unwrap()
             .unwrap(),
             Value::Date(datetime_utc)
         );
