@@ -25,10 +25,11 @@ use hurl_core::error::Error;
 use hurl_core::parser;
 
 use crate::http;
+use crate::http::Call;
 use crate::runner::core::*;
 use crate::runner::runner_options::RunnerOptions;
 use crate::runner::{entry, Value};
-use crate::util::logger::{Logger, LoggerBuilder};
+use crate::util::logger::{ErrorFormat, Logger, LoggerOptions, LoggerOptionsBuilder};
 
 /// Runs a Hurl `content` and returns a [`HurlResult`] upon completion.
 ///
@@ -38,8 +39,8 @@ use crate::util::logger::{Logger, LoggerBuilder};
 /// ```
 /// use std::collections::HashMap;
 /// use hurl::runner;
-/// use hurl::runner::{Value, RunnerOptionsBuilder, Verbosity};
-/// use hurl::util::logger::LoggerBuilder;
+/// use hurl::runner::{Value, RunnerOptionsBuilder};
+/// use hurl::util::logger::{LoggerOptionsBuilder, Verbosity};
 ///
 /// // A simple Hurl sample
 /// let content = r#"
@@ -47,12 +48,13 @@ use crate::util::logger::{Logger, LoggerBuilder};
 /// HTTP 200
 /// "#;
 ///
-/// // Define runner options and logger
-/// let options = RunnerOptionsBuilder::new()
+/// // Define runner and logger options
+/// let runner_opts = RunnerOptionsBuilder::new()
 ///     .follow_location(true)
+///     .build();
+/// let logger_opts = LoggerOptionsBuilder::new()
 ///     .verbosity(Some(Verbosity::Verbose))
 ///     .build();
-/// let logger = LoggerBuilder::new().build();
 ///
 /// // Set variables
 /// let mut variables = HashMap::default();
@@ -61,9 +63,9 @@ use crate::util::logger::{Logger, LoggerBuilder};
 /// // Run the Hurl sample
 /// let result = runner::run(
 ///     content,
-///     &options,
+///     &runner_opts,
 ///     &variables,
-///     &logger
+///     &logger_opts
 /// );
 /// assert!(result.unwrap().success);
 /// ```
@@ -71,8 +73,10 @@ pub fn run(
     content: &str,
     runner_options: &RunnerOptions,
     variables: &HashMap<String, Value>,
-    logger: &Logger,
+    logger_options: &LoggerOptions,
 ) -> Result<HurlResult, String> {
+    let logger = Logger::from(logger_options);
+
     // Try to parse the content
     let hurl_file = parser::parse_hurl_file(content);
     let hurl_file = match hurl_file {
@@ -83,7 +87,7 @@ pub fn run(
         }
     };
 
-    log_run_info(&hurl_file, runner_options, variables, logger);
+    log_run_info(&hurl_file, runner_options, variables, &logger);
 
     // Now, we have a syntactically correct HurlFile instance, we can run it.
     let cookie_input_file = runner_options.cookie_input_file.clone();
@@ -105,18 +109,10 @@ pub fn run(
         }
         let entry = &hurl_file.entries[entry_index - 1];
 
-        // We compute these new overridden options for this entry, before entering into the `run`
+        // We compute the new logger for this entry, before entering into the `run`
         // function because entry options can modify the logger and we want the preamble
         // "Executing entry..." to be displayed based on the entry level verbosity.
-        let entry_verbosity = entry::get_entry_verbosity(entry, &runner_options.verbosity);
-        let logger = LoggerBuilder::new()
-            .filename(&logger.filename)
-            .color(logger.color)
-            .verbose(entry_verbosity.is_some())
-            .test(logger.test)
-            .progress_bar(entry_verbosity.is_none() && logger.progress_bar)
-            .build();
-
+        let logger = get_entry_logger(entry, logger_options);
         if let Some(pre_entry) = runner_options.pre_entry {
             let exit = pre_entry(entry.clone());
             if exit {
@@ -133,9 +129,9 @@ pub fn run(
 
         logger.test_progress(entry_index, n);
 
-        let options_result =
-            entry::get_entry_options(entry, runner_options, &mut variables, &logger);
-        let entry_result = match &options_result {
+        // The real execution of the entry happens here, with the overridden entry options.
+        let options = entry::get_entry_options(entry, runner_options, &mut variables, &logger);
+        let entry_result = match &options {
             Ok(options) => entry::run(
                 entry,
                 entry_index,
@@ -157,50 +153,32 @@ pub fn run(
 
         // Check if we need to retry.
         let has_error = !entry_result.errors.is_empty();
-        let (retry, retry_max_count, retry_interval) = match &options_result {
-            Ok(options) => (
-                options.retry,
-                options.retry_max_count,
-                options.retry_interval,
-            ),
-            Err(_) => (
-                runner_options.retry,
-                runner_options.retry_max_count,
-                runner_options.retry_interval,
-            ),
+        let (retry_opts, retry_interval) = match &options {
+            Ok(options) => (options.retry, options.retry_interval),
+            Err(_) => (runner_options.retry, runner_options.retry_interval),
         };
-        let retry_max_reached = match retry_max_count {
-            None => false,
-            Some(r) => retry_count > r,
+        // The retry threshold can only reached with a finite positive number of retries
+        let retry_max_reached = if let Retry::Finite(r) = retry_opts {
+            retry_count > r
+        } else {
+            false
         };
+        // If `retry_max_reached` is true, we print now a warning, before displaying
+        // any assert error so any potential error is the last thing displayed to the user.
+        // If `retry_max_reached` is not true (for instance `retry`is true, or there is no error
+        // we first log the error and a potential warning about retrying.
+        logger.test_erase_line();
         if retry_max_reached {
-            logger.debug("");
             logger.debug_important("Retry max count reached, no more retry");
+            logger.debug("");
         }
-        let retry = retry && !retry_max_reached && has_error;
 
-        // If we're going to retry the entry, we log error only in verbose. Otherwise,
-        // we log error on stderr.
-        for e in &entry_result.errors {
-            if retry {
-                if logger.verbose {
-                    logger.test_erase_line();
-                    logger.debug_error(content, e);
-                }
-            } else {
-                logger.test_erase_line();
-                logger.error_rich(content, e);
-            }
+        let retry = !matches!(retry_opts, Retry::None) && !retry_max_reached && has_error;
+        if has_error {
+            log_errors(&entry_result, content, retry, &logger);
         }
         entries.push(entry_result);
 
-        if let Some(post_entry) = runner_options.post_entry {
-            let exit = post_entry();
-            if exit {
-                break;
-            }
-        }
-
         if retry {
             let delay = retry_interval.as_millis();
             logger.debug("");
@@ -208,9 +186,21 @@ pub fn run(
                 format!("Retry entry {entry_index} (x{retry_count} pause {delay} ms)").as_str(),
             );
             retry_count += 1;
+            // If we retry the entry, we do not want to display a 'blank' progress bar
+            // during the sleep delay. During the pause, we artificially show the previsoulsy
+            // erased progress line.
+            logger.test_progress(entry_index, n);
             thread::sleep(retry_interval);
+            logger.test_erase_line();
             continue;
         }
+
+        if let Some(post_entry) = runner_options.post_entry {
+            let exit = post_entry();
+            if exit {
+                break;
+            }
+        }
         if runner_options.fail_fast && has_error {
             break;
         }
@@ -220,8 +210,6 @@ pub fn run(
         retry_count = 1;
     }
 
-    logger.test_erase_line();
-
     let time_in_ms = start.elapsed().as_millis();
     let cookies = http_client.get_cookie_storage();
     let success = is_success(&entries);
@@ -337,9 +325,6 @@ fn log_run_info(
         logger.debug(format!("    proxy: {proxy}").as_str());
     }
     logger.debug(format!("    retry: {}", runner_options.retry).as_str());
-    if let Some(n) = runner_options.retry_max_count {
-        logger.debug(format!("    retry max count: {n}").as_str());
-    }
     if !variables.is_empty() {
         logger.debug_important("Variables:");
         for (name, value) in variables.iter() {
@@ -351,3 +336,44 @@ fn log_run_info(
             .debug(format!("Executing {}/{} entries", to_entry, hurl_file.entries.len()).as_str());
     }
 }
+
+/// Logs runner `errors`.
+/// If we're going to `retry` the entry, we log errors only in verbose. Otherwise, we log error on stderr.
+fn log_errors(entry_result: &EntryResult, content: &str, retry: bool, logger: &Logger) {
+    if retry {
+        entry_result
+            .errors
+            .iter()
+            .for_each(|e| logger.debug_error(content, e));
+        return;
+    }
+
+    if logger.error_format == ErrorFormat::Long {
+        if let Some(Call { response, .. }) = entry_result.calls.last() {
+            response.log_all(logger);
+        } else {
+            logger.info("<No HTTP response>");
+            logger.info("");
+        }
+    }
+    entry_result
+        .errors
+        .iter()
+        .for_each(|e| logger.error_rich(content, e));
+}
+
+/// Creates a new logger for this entry.
+/// Verbosity can be overridden at entry level with an Options section so each
+/// entry has its own logger.
+fn get_entry_logger(entry: &Entry, logger_options: &LoggerOptions) -> Logger {
+    let entry_verbosity = entry::get_entry_verbosity(entry, &logger_options.verbosity);
+    let entry_logger_options = LoggerOptionsBuilder::new()
+        .color(logger_options.color)
+        .filename(&logger_options.filename)
+        .error_format(logger_options.error_format)
+        .progress_bar(entry_verbosity.is_none() && logger_options.progress_bar)
+        .verbosity(entry_verbosity)
+        .test(logger_options.test)
+        .build();
+    Logger::from(&entry_logger_options)
+}
