@@ -17,9 +17,8 @@
  */
 use std::time::Duration;
 
-use hurl_core::ast::Entry;
+use hurl_core::ast::{Entry, Retry};
 
-use crate::runner::Verbosity;
 use crate::util::path::ContextDir;
 
 pub struct RunnerOptionsBuilder {
@@ -37,19 +36,18 @@ pub struct RunnerOptionsBuilder {
     insecure: bool,
     max_redirect: Option<usize>,
     no_proxy: Option<String>,
+    path_as_is: bool,
     post_entry: Option<fn() -> bool>,
     pre_entry: Option<fn(Entry) -> bool>,
     proxy: Option<String>,
     resolves: Vec<String>,
-    retry: bool,
+    retry: Retry,
     retry_interval: Duration,
-    retry_max_count: Option<usize>,
     ssl_no_revoke: bool,
     timeout: Duration,
     to_entry: Option<usize>,
     user: Option<String>,
     user_agent: Option<String>,
-    verbosity: Option<Verbosity>,
 }
 
 impl Default for RunnerOptionsBuilder {
@@ -69,19 +67,18 @@ impl Default for RunnerOptionsBuilder {
             insecure: false,
             max_redirect: Some(50),
             no_proxy: None,
+            path_as_is: false,
             post_entry: None,
             pre_entry: None,
             proxy: None,
             resolves: vec![],
-            retry: false,
+            retry: Retry::None,
             retry_interval: Duration::from_millis(1000),
-            retry_max_count: Some(10),
             ssl_no_revoke: false,
             timeout: Duration::from_secs(300),
             to_entry: None,
             user: None,
             user_agent: None,
-            verbosity: None,
         }
     }
 }
@@ -186,6 +183,12 @@ impl RunnerOptionsBuilder {
         self
     }
 
+    /// Sets the path-as-is flag.
+    pub fn path_as_is(&mut self, path_as_is: bool) -> &mut Self {
+        self.path_as_is = path_as_is;
+        self
+    }
+
     /// Sets list of hosts which do not use a proxy.
     pub fn no_proxy(&mut self, no_proxy: Option<String>) -> &mut Self {
         self.no_proxy = no_proxy;
@@ -220,10 +223,10 @@ impl RunnerOptionsBuilder {
         self
     }
 
-    /// Retries requests if any error occurs (asserts, captures, runtimes etc...).
+    /// Sets maximum number of retries.
     ///
-    /// Default is false.
-    pub fn retry(&mut self, retry: bool) -> &mut Self {
+    /// Default is 0.
+    pub fn retry(&mut self, retry: Retry) -> &mut Self {
         self.retry = retry;
         self
     }
@@ -236,14 +239,6 @@ impl RunnerOptionsBuilder {
         self
     }
 
-    /// Sets maximum number of retries.
-    ///
-    /// Default is 10.
-    pub fn retry_max_count(&mut self, retry_max_count: Option<usize>) -> &mut Self {
-        self.retry_max_count = retry_max_count;
-        self
-    }
-
     pub fn ssl_no_revoke(&mut self, ssl_no_revoke: bool) -> &mut Self {
         self.ssl_no_revoke = ssl_no_revoke;
         self
@@ -275,12 +270,6 @@ impl RunnerOptionsBuilder {
         self
     }
 
-    /// Sets verbosity level.
-    pub fn verbosity(&mut self, verbosity: Option<Verbosity>) -> &mut Self {
-        self.verbosity = verbosity;
-        self
-    }
-
     /// Create an instance of [`RunnerOptions`].
     pub fn build(&self) -> RunnerOptions {
         RunnerOptions {
@@ -298,19 +287,18 @@ impl RunnerOptionsBuilder {
             insecure: self.insecure,
             max_redirect: self.max_redirect,
             no_proxy: self.no_proxy.clone(),
+            path_as_is: self.path_as_is,
             post_entry: self.post_entry,
             pre_entry: self.pre_entry,
             proxy: self.proxy.clone(),
             resolves: self.resolves.clone(),
             retry: self.retry,
             retry_interval: self.retry_interval,
-            retry_max_count: self.retry_max_count,
             ssl_no_revoke: self.ssl_no_revoke,
             timeout: self.timeout,
             to_entry: self.to_entry,
             user: self.user.clone(),
             user_agent: self.user_agent.clone(),
-            verbosity: self.verbosity.clone(),
         }
     }
 }
@@ -331,19 +319,18 @@ pub struct RunnerOptions {
     pub(crate) insecure: bool,
     pub(crate) max_redirect: Option<usize>,
     pub(crate) no_proxy: Option<String>,
+    pub(crate) path_as_is: bool,
     pub(crate) post_entry: Option<fn() -> bool>,
     pub(crate) pre_entry: Option<fn(Entry) -> bool>,
     pub(crate) proxy: Option<String>,
     pub(crate) resolves: Vec<String>,
-    pub(crate) retry: bool,
+    pub(crate) retry: Retry,
     pub(crate) retry_interval: Duration,
-    pub(crate) retry_max_count: Option<usize>,
     pub(crate) ssl_no_revoke: bool,
     pub(crate) timeout: Duration,
     pub(crate) to_entry: Option<usize>,
     pub(crate) user: Option<String>,
     pub(crate) user_agent: Option<String>,
-    pub(crate) verbosity: Option<Verbosity>,
 }
 
 impl Default for RunnerOptions {
