@@ -89,6 +89,15 @@ impl Request {
         }
         None
     }
+
+    pub fn options(&self) -> Vec<EntryOption> {
+        for section in &self.sections {
+            if let SectionValue::Options(options) = &section.value {
+                return options.clone();
+            }
+        }
+        vec![]
+    }
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
@@ -128,24 +137,7 @@ impl Response {
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
-pub enum Method {
-    Get,
-    Head,
-    Post,
-    Put,
-    Delete,
-    Connect,
-    Options,
-    Trace,
-    Patch,
-    Link,
-    Unlink,
-    Purge,
-    Lock,
-    Unlock,
-    Propfind,
-    View,
-}
+pub struct Method(pub String);
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct Version {
@@ -723,9 +715,10 @@ pub enum EntryOption {
     Insecure(InsecureOption),
     FollowLocation(FollowLocationOption),
     MaxRedirect(MaxRedirectOption),
+    PathAsIs(PathAsIsOption),
+    Proxy(ProxyOption),
     Retry(RetryOption),
     RetryInterval(RetryIntervalOption),
-    RetryMaxCount(RetryMaxCountOption),
     Variable(VariableOption),
     Verbose(VerboseOption),
     VeryVerbose(VeryVerboseOption),
@@ -782,7 +775,7 @@ pub struct ClientKeyOption {
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
-pub struct RetryOption {
+pub struct PathAsIsOption {
     pub line_terminators: Vec<LineTerminator>,
     pub space0: Whitespace,
     pub space1: Whitespace,
@@ -791,6 +784,16 @@ pub struct RetryOption {
     pub line_terminator0: LineTerminator,
 }
 
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct ProxyOption {
+    pub line_terminators: Vec<LineTerminator>,
+    pub space0: Whitespace,
+    pub space1: Whitespace,
+    pub space2: Whitespace,
+    pub value: String,
+    pub line_terminator0: LineTerminator,
+}
+
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct RetryIntervalOption {
     pub line_terminators: Vec<LineTerminator>,
@@ -802,12 +805,12 @@ pub struct RetryIntervalOption {
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
-pub struct RetryMaxCountOption {
+pub struct RetryOption {
     pub line_terminators: Vec<LineTerminator>,
     pub space0: Whitespace,
     pub space1: Whitespace,
     pub space2: Whitespace,
-    pub value: usize,
+    pub value: Retry,
     pub line_terminator0: LineTerminator,
 }
 
@@ -889,6 +892,10 @@ pub enum FilterValue {
     Count,
     DaysAfterNow,
     DaysBeforeNow,
+    Decode {
+        space0: Whitespace,
+        encoding: Template,
+    },
     Format {
         space0: Whitespace,
         fmt: Template,
@@ -920,4 +927,15 @@ pub enum FilterValue {
     ToInt,
     UrlDecode,
     UrlEncode,
+    XPath {
+        space0: Whitespace,
+        expr: Template,
+    },
+}
+
+#[derive(Clone, Debug, PartialEq, Eq, Copy)]
+pub enum Retry {
+    None,
+    Finite(usize),
+    Infinite,
 }
