@@ -21,25 +21,7 @@ use crate::ast::core::*;
 
 impl fmt::Display for Method {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        let s = match self {
-            Method::Get => "GET",
-            Method::Head => "HEAD",
-            Method::Post => "POST",
-            Method::Put => "PUT",
-            Method::Delete => "DELETE",
-            Method::Connect => "CONNECT",
-            Method::Options => "OPTIONS",
-            Method::Trace => "TRACE",
-            Method::Patch => "PATCH",
-            Method::Link => "LINK",
-            Method::Unlink => "UNLINK",
-            Method::Purge => "PURGE",
-            Method::Lock => "LOCK",
-            Method::Unlock => "UNLOCK",
-            Method::Propfind => "PROPFIND",
-            Method::View => "VIEW",
-        };
-        write!(f, "{s}")
+        write!(f, "{}", self.0)
     }
 }
 
@@ -176,6 +158,25 @@ impl fmt::Display for MultilineString {
     }
 }
 
+impl fmt::Display for VariableDefinition {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        write!(f, "{}={}", self.name, self.value)
+    }
+}
+
+impl fmt::Display for VariableValue {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        let s = match self {
+            VariableValue::Null { .. } => "null".to_string(),
+            VariableValue::Bool(value) => value.to_string(),
+            VariableValue::Integer(n) => n.to_string(),
+            VariableValue::Float(x) => x.to_string(),
+            VariableValue::String(s) => s.to_string(),
+        };
+        write!(f, "{}", s)
+    }
+}
+
 impl PredicateFuncValue {
     pub fn name(&self) -> String {
         match self {
@@ -238,6 +239,17 @@ impl PredicateFuncValue {
     }
 }
 
+impl fmt::Display for Retry {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        let value = match self {
+            Retry::None => 0,
+            Retry::Finite(n) => *n as i32,
+            Retry::Infinite => -1,
+        };
+        write!(f, "{}", value)
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
