@@ -209,9 +209,10 @@ impl HtmlFormatter {
             EntryOption::Insecure(option) => self.fmt_insecure_option(option),
             EntryOption::FollowLocation(option) => self.fmt_follow_location_option(option),
             EntryOption::MaxRedirect(option) => self.fmt_max_redirect_option(option),
+            EntryOption::PathAsIs(option) => self.fmt_path_as_is_option(option),
+            EntryOption::Proxy(option) => self.fmt_proxy_option(option),
             EntryOption::Retry(option) => self.fmt_retry_option(option),
             EntryOption::RetryInterval(option) => self.fmt_retry_interval_option(option),
-            EntryOption::RetryMaxCount(option) => self.fmt_retry_max_count_option(option),
             EntryOption::Variable(option) => self.fmt_variable_option(option),
             EntryOption::Verbose(option) => self.fmt_verbose_option(option),
             EntryOption::VeryVerbose(option) => self.fmt_very_verbose_option(option),
@@ -309,6 +310,32 @@ impl HtmlFormatter {
         self.fmt_lt(&option.line_terminator0);
     }
 
+    fn fmt_path_as_is_option(&mut self, option: &PathAsIsOption) {
+        self.fmt_lts(&option.line_terminators);
+        self.fmt_span_open("line");
+        self.fmt_space(&option.space0);
+        self.fmt_string("path-as-is");
+        self.fmt_space(&option.space1);
+        self.buffer.push(':');
+        self.fmt_space(&option.space2);
+        self.fmt_bool(option.value);
+        self.fmt_span_close();
+        self.fmt_lt(&option.line_terminator0);
+    }
+
+    fn fmt_proxy_option(&mut self, option: &ProxyOption) {
+        self.fmt_lts(&option.line_terminators);
+        self.fmt_span_open("line");
+        self.fmt_space(&option.space0);
+        self.fmt_string("proxy");
+        self.fmt_space(&option.space1);
+        self.buffer.push(':');
+        self.fmt_space(&option.space2);
+        self.fmt_string(&option.value);
+        self.fmt_span_close();
+        self.fmt_lt(&option.line_terminator0);
+    }
+
     fn fmt_retry_option(&mut self, option: &RetryOption) {
         self.fmt_lts(&option.line_terminators);
         self.fmt_span_open("line");
@@ -317,7 +344,7 @@ impl HtmlFormatter {
         self.fmt_space(&option.space1);
         self.buffer.push(':');
         self.fmt_space(&option.space2);
-        self.fmt_bool(option.value);
+        self.fmt_retry(option.value);
         self.fmt_span_close();
         self.fmt_lt(&option.line_terminator0);
     }
@@ -335,19 +362,6 @@ impl HtmlFormatter {
         self.fmt_lt(&option.line_terminator0);
     }
 
-    fn fmt_retry_max_count_option(&mut self, option: &RetryMaxCountOption) {
-        self.fmt_lts(&option.line_terminators);
-        self.fmt_span_open("line");
-        self.fmt_space(&option.space0);
-        self.fmt_string("retry-max-count");
-        self.fmt_space(&option.space1);
-        self.buffer.push(':');
-        self.fmt_space(&option.space2);
-        self.fmt_number(option.value);
-        self.fmt_span_close();
-        self.fmt_lt(&option.line_terminator0);
-    }
-
     fn fmt_variable_option(&mut self, option: &VariableOption) {
         self.fmt_lts(&option.line_terminators);
         self.fmt_span_open("line");
@@ -562,7 +576,11 @@ impl HtmlFormatter {
             CertificateAttributeName::ExpireDate => "Expire-Date",
             CertificateAttributeName::SerialNumber => "Serial-Number",
         };
-        self.fmt_string(value);
+        self.fmt_span_open("string");
+        self.buffer.push('"');
+        self.buffer.push_str(value);
+        self.buffer.push('"');
+        self.fmt_span_close();
     }
 
     fn fmt_assert(&mut self, assert: &Assert) {
@@ -884,6 +902,11 @@ impl HtmlFormatter {
             FilterValue::Count => self.fmt_span("filter-type", "count"),
             FilterValue::DaysAfterNow => self.fmt_span("filter-type", "daysAfterNow"),
             FilterValue::DaysBeforeNow => self.fmt_span("filter-type", "daysBeforeNow"),
+            FilterValue::Decode { space0, encoding } => {
+                self.fmt_span("filter-type", "decode");
+                self.fmt_space(space0);
+                self.fmt_template(encoding);
+            }
             FilterValue::Format { space0, fmt } => {
                 self.fmt_span("filter-type", "format");
                 self.fmt_space(space0);
@@ -926,6 +949,11 @@ impl HtmlFormatter {
             FilterValue::ToInt => self.fmt_span("filter-type", "toInt"),
             FilterValue::UrlDecode => self.fmt_span("filter-type", "urlDecode"),
             FilterValue::UrlEncode => self.fmt_span("filter-type", "urlEncode"),
+            FilterValue::XPath { space0, expr } => {
+                self.fmt_span("filter-type", "xpath");
+                self.fmt_space(space0);
+                self.fmt_template(expr);
+            }
         };
     }
 
@@ -939,6 +967,14 @@ impl HtmlFormatter {
             self.fmt_lt(line_terminator);
         }
     }
+
+    fn fmt_retry(&mut self, retry: Retry) {
+        match retry {
+            Retry::Finite(n) => self.fmt_span("number", &n.to_string()),
+            Retry::Infinite => self.fmt_span("number", "-1"),
+            _ => {}
+        };
+    }
 }
 
 fn escape_xml(s: &str) -> String {
