@@ -15,13 +15,12 @@
  * limitations under the License.
  *
  */
-use super::combinators::*;
-use super::reader::Reader;
-use super::ParseResult;
 use crate::ast::*;
+use crate::parser::combinators::*;
 use crate::parser::json::object_value;
 use crate::parser::primitives::*;
-use crate::parser::{template, Error, ParseError};
+use crate::parser::reader::Reader;
+use crate::parser::{template, Error, ParseError, ParseResult};
 
 pub fn multiline_string(reader: &mut Reader) -> ParseResult<'static, MultilineString> {
     try_literal("```", reader)?;
@@ -84,7 +83,7 @@ fn graphql(reader: &mut Reader) -> ParseResult<'static, MultilineString> {
     let mut chars = vec![];
 
     let start = reader.state.pos.clone();
-    while !reader.remaining().starts_with("```") && !reader.is_eof() {
+    while reader.peek_n(3) != "```" && !reader.is_eof() {
         let pos = reader.state.pos.clone();
         let c = reader.read().unwrap();
         chars.push((c, c.to_string(), pos));
@@ -234,7 +233,7 @@ fn multiline_string_value(reader: &mut Reader) -> ParseResult<'static, Template>
     let mut chars = vec![];
 
     let start = reader.state.pos.clone();
-    while !reader.remaining().starts_with("```") && !reader.is_eof() {
+    while reader.peek_n(3) != "```" && !reader.is_eof() {
         let pos = reader.state.pos.clone();
         let c = reader.read().unwrap();
         chars.push((c, c.to_string(), pos));
@@ -263,7 +262,7 @@ fn oneline_string_value(reader: &mut Reader) -> ParseResult<'static, Template> {
     let mut chars = vec![];
 
     let start = reader.state.pos.clone();
-    while !reader.remaining().starts_with("```") && !reader.is_eof() {
+    while reader.peek_n(3) != "```" && !reader.is_eof() {
         let pos = reader.state.pos.clone();
         let c = reader.read().unwrap();
         if c == '\n' {
@@ -301,7 +300,7 @@ mod tests {
 
     #[test]
     fn test_multiline_string_text() {
-        let mut reader = Reader::init("```\nline1\nline2\nline3\n```");
+        let mut reader = Reader::new("```\nline1\nline2\nline3\n```");
         assert_eq!(
             multiline_string(&mut reader).unwrap(),
             MultilineString::Text(Text {
@@ -324,7 +323,7 @@ mod tests {
             })
         );
 
-        let mut reader = Reader::init("```         \nline1\nline2\nline3\n```");
+        let mut reader = Reader::new("```         \nline1\nline2\nline3\n```");
         assert_eq!(
             multiline_string(&mut reader).unwrap(),
             MultilineString::Text(Text {
@@ -350,7 +349,7 @@ mod tests {
 
     #[test]
     fn test_multiline_string_json() {
-        let mut reader = Reader::init("```json\nline1\nline2\nline3\n```");
+        let mut reader = Reader::new("```json\nline1\nline2\nline3\n```");
         assert_eq!(
             multiline_string(&mut reader).unwrap(),
             MultilineString::Json(Text {
@@ -376,7 +375,7 @@ mod tests {
 
     #[test]
     fn test_multiline_string_graphql() {
-        let mut reader = Reader::init("```graphql\nline1\nline2\nline3\n```");
+        let mut reader = Reader::new("```graphql\nline1\nline2\nline3\n```");
         assert_eq!(
             multiline_string(&mut reader).unwrap(),
             MultilineString::GraphQl(GraphQl {
@@ -400,7 +399,7 @@ mod tests {
             })
         );
 
-        let mut reader = Reader::init("```graphql      \nline1\nline2\nline3\n```");
+        let mut reader = Reader::new("```graphql      \nline1\nline2\nline3\n```");
         assert_eq!(
             multiline_string(&mut reader).unwrap(),
             MultilineString::GraphQl(GraphQl {
@@ -433,14 +432,14 @@ mod tests {
         ];
 
         for text in datas.iter() {
-            let mut reader = Reader::init(text);
+            let mut reader = Reader::new(text);
             assert!(multiline_string(&mut reader).is_err())
         }
     }
 
     #[test]
     fn test_multiline_string_empty() {
-        let mut reader = Reader::init("``````");
+        let mut reader = Reader::new("``````");
         assert_eq!(
             multiline_string(&mut reader).unwrap(),
             MultilineString::OneLineText(Template {
@@ -450,7 +449,7 @@ mod tests {
             })
         );
 
-        let mut reader = Reader::init("```\n```");
+        let mut reader = Reader::new("```\n```");
         assert_eq!(
             multiline_string(&mut reader).unwrap(),
             MultilineString::Text(Text {
@@ -469,7 +468,7 @@ mod tests {
                 },
             })
         );
-        let mut reader = Reader::init("```\r\n```");
+        let mut reader = Reader::new("```\r\n```");
         assert_eq!(
             multiline_string(&mut reader).unwrap(),
             MultilineString::Text(Text {
@@ -492,7 +491,7 @@ mod tests {
 
     #[test]
     fn test_multiline_string_hello() {
-        let mut reader = Reader::init("```Hello World!```");
+        let mut reader = Reader::new("```Hello World!```");
         assert_eq!(
             multiline_string(&mut reader).unwrap(),
             MultilineString::OneLineText(Template {
@@ -508,7 +507,7 @@ mod tests {
 
     #[test]
     fn test_multiline_string_base64_prefix() {
-        let mut reader = Reader::init("```base64_inline```");
+        let mut reader = Reader::new("```base64_inline```");
         assert_eq!(
             multiline_string(&mut reader).unwrap(),
             MultilineString::OneLineText(Template {
@@ -524,7 +523,7 @@ mod tests {
 
     #[test]
     fn test_multiline_string_csv() {
-        let mut reader = Reader::init("```\nline1\nline2\nline3\n```");
+        let mut reader = Reader::new("```\nline1\nline2\nline3\n```");
         assert_eq!(
             multiline_string(&mut reader).unwrap(),
             MultilineString::Text(Text {
@@ -550,7 +549,7 @@ mod tests {
 
     #[test]
     fn test_multiline_string_one_empty_line() {
-        let mut reader = Reader::init("```\n\n```");
+        let mut reader = Reader::new("```\n\n```");
         assert_eq!(
             multiline_string(&mut reader).unwrap(),
             MultilineString::Text(Text {
@@ -574,7 +573,7 @@ mod tests {
         );
 
         // One cr
-        let mut reader = Reader::init("```\n\r\n````");
+        let mut reader = Reader::new("```\n\r\n````");
         assert_eq!(
             multiline_string(&mut reader).unwrap(),
             MultilineString::Text(Text {
@@ -600,7 +599,7 @@ mod tests {
 
     #[test]
     fn test_multiline_string_error() {
-        let mut reader = Reader::init("xxx");
+        let mut reader = Reader::new("xxx");
         let error = multiline_string(&mut reader).err().unwrap();
         assert_eq!(error.pos, Pos { line: 1, column: 1 });
         assert_eq!(
@@ -611,13 +610,13 @@ mod tests {
         );
         assert!(error.recoverable);
 
-        let mut reader = Reader::init("```\nxxx");
+        let mut reader = Reader::new("```\nxxx");
         let error = multiline_string(&mut reader).err().unwrap();
         assert_eq!(error.pos, Pos { line: 1, column: 4 });
         assert_eq!(error.inner, ParseError::Multiline);
         assert!(!error.recoverable);
 
-        let mut reader = Reader::init("```xxx");
+        let mut reader = Reader::new("```xxx");
         let error = multiline_string(&mut reader).err().unwrap();
         assert_eq!(error.pos, Pos { line: 1, column: 7 });
         assert_eq!(
@@ -631,7 +630,7 @@ mod tests {
 
     #[test]
     fn test_multiline_string_value() {
-        let mut reader = Reader::init("```");
+        let mut reader = Reader::new("```");
         assert_eq!(
             multiline_string_value(&mut reader).unwrap(),
             Template {
@@ -642,7 +641,7 @@ mod tests {
         );
         assert_eq!(reader.state.cursor, 3);
 
-        let mut reader = Reader::init("hello```");
+        let mut reader = Reader::new("hello```");
         assert_eq!(
             multiline_string_value(&mut reader).unwrap(),
             Template {
@@ -659,7 +658,7 @@ mod tests {
 
     #[test]
     fn test_multiline_string_graphql_with_variables() {
-        let mut reader = Reader::init(
+        let mut reader = Reader::new(
             r#"```graphql
 query Human($name: String!) {
   human(name: $name) {
@@ -738,7 +737,7 @@ variables {
 
     #[test]
     fn test_multiline_string_graphql_with_variables_error() {
-        let mut reader = Reader::init(
+        let mut reader = Reader::new(
             r#"```graphql
 query Human($name: String!) {
   human(name: $name) {
@@ -766,7 +765,7 @@ variables
 
     #[test]
     fn test_multiline_string_graphql_with_variables_not_an_object() {
-        let mut reader = Reader::init(
+        let mut reader = Reader::new(
             r#"```graphql
 query Human($name: String!) {
   human(name: $name) {
