@@ -15,8 +15,28 @@
  * limitations under the License.
  *
  */
+use std::cmp::min;
+
 use crate::ast::Pos;
 
+/// Represents a text reader.
+///
+/// The `Reader` implements methods to read a stream of text. A reader manages
+/// an internal `state` which is the position of the current cursor within the reader's buffer.
+/// Methods like [`Reader::read`], [`Reader::read_while`], [`Reader::read_while_escaping`]
+/// do advance the internal reader's`state`. Other methods, like [`Reader::peek`], [`Reader::peek_n`]
+/// allows to get the next chars in the buffer without modifying the current reader state.
+///
+/// # Example
+/// ```
+///  use hurl_core::parser::Reader;
+///
+///  let mut reader = Reader::new("hi");
+///  let state = reader.state.cursor; // cursor is 0
+///  let eof = reader.is_eof();
+///  let val = reader.peek_n(2); // val = "hi"
+///  let val = reader.read().unwrap(); // val = 'h'
+/// ```
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct Reader {
     pub buffer: Vec<char>,
@@ -30,7 +50,8 @@ pub struct ReaderState {
 }
 
 impl Reader {
-    pub fn init(s: &str) -> Reader {
+    /// Creates a new reader.
+    pub fn new(s: &str) -> Reader {
         Reader {
             buffer: s.chars().collect(),
             state: ReaderState {
@@ -40,10 +61,12 @@ impl Reader {
         }
     }
 
+    /// Returns true if the reader has read all the buffer, false otherwise.
     pub fn is_eof(&self) -> bool {
         self.state.cursor == self.buffer.len()
     }
 
+    /// Returns the next char from the buffer advancing the internal state.
     pub fn read(&mut self) -> Option<char> {
         match self.buffer.get(self.state.cursor) {
             None => None,
@@ -61,10 +84,20 @@ impl Reader {
         }
     }
 
-    pub fn peek(&mut self) -> Option<char> {
-        self.buffer.get(self.state.cursor).copied()
+    /// Returns `count` chars from the buffer advancing the internal state.
+    /// This methods can returns less than `count` chars if there is not enough chars in the buffer.
+    pub fn read_n(&mut self, count: usize) -> String {
+        let mut s = String::from("");
+        for _ in 0..count {
+            match self.read() {
+                None => {}
+                Some(c) => s.push(c),
+            }
+        }
+        s
     }
 
+    /// Returns chars from the buffer while `predicate` is true, advancing the internal state.
     pub fn read_while(&mut self, predicate: fn(&char) -> bool) -> String {
         let mut s = String::from("");
         loop {
@@ -105,20 +138,21 @@ impl Reader {
         }
     }
 
-    // assume that you still have count characters to read in your buffer
-    pub fn read_n(&mut self, count: usize) -> String {
-        let mut s = String::from("");
-        for _ in 0..count {
-            match self.read() {
-                None => {}
-                Some(c) => s.push(c),
-            }
-        }
-        s
+    /// Returns the next char from the buffer without advancing the internal state.
+    pub fn peek(&mut self) -> Option<char> {
+        self.buffer.get(self.state.cursor).copied()
+    }
+
+    /// Returns the `count` char from the buffer without advancing the internal state.
+    /// This methods can returns less than `count` chars if there is not enough chars in the buffer.
+    pub fn peek_n(&self, count: usize) -> String {
+        let start = self.state.cursor;
+        let end = min(start + count, self.buffer.len());
+        self.buffer[start..end].iter().collect()
     }
 
     pub fn try_literal(&mut self, value: &str) -> bool {
-        if self.remaining().starts_with(value.to_string().as_str()) {
+        if self.peek_n(value.len()) == value {
             self.read_n(value.len());
             true
         } else {
@@ -126,19 +160,9 @@ impl Reader {
         }
     }
 
-    pub fn remaining(&self) -> String {
-        self.buffer.as_slice()[self.state.cursor..self.buffer.len()]
-            .iter()
-            .collect()
-    }
-
-    pub fn slice(&self, start: usize, end: usize) -> String {
-        self.buffer.as_slice()[start..end].iter().collect()
-    }
-
-    pub fn from(&self, start: usize) -> String {
+    pub fn peek_back(&self, start: usize) -> String {
         let end = self.state.cursor;
-        self.buffer.as_slice()[start..end].iter().collect()
+        self.buffer[start..end].iter().collect()
     }
 }
 
@@ -152,10 +176,10 @@ mod tests {
 
     #[test]
     fn test_reader() {
-        let mut reader = Reader::init("hi");
+        let mut reader = Reader::new("hi");
         assert_eq!(reader.state.cursor, 0);
         assert!(!reader.is_eof());
-        assert_eq!(reader.remaining(), "hi".to_string());
+        assert_eq!(reader.peek_n(2), "hi".to_string());
 
         assert_eq!(reader.read().unwrap(), 'h');
         assert_eq!(reader.state.cursor, 1);
@@ -168,11 +192,11 @@ mod tests {
 
     #[test]
     fn test_try_predicate() {
-        let mut reader = Reader::init("hi");
+        let mut reader = Reader::new("hi");
         assert!(reader.try_literal("hi"));
         assert_eq!(reader.state.cursor, 2);
 
-        let mut reader = Reader::init("hello");
+        let mut reader = Reader::new("hello");
         assert!(!reader.try_literal("hi"));
         assert_eq!(reader.state.cursor, 0);
     }
