@@ -364,9 +364,10 @@ fn option(reader: &mut Reader) -> ParseResult<'static, EntryOption> {
             option_insecure,
             option_follow_location,
             option_max_redirect,
+            option_path_as_is,
+            option_proxy,
             option_retry,
             option_retry_interval,
-            option_retry_max_count,
             option_variable,
             option_verbose,
             option_very_verbose,
@@ -531,17 +532,17 @@ fn option_max_redirect(reader: &mut Reader) -> ParseResult<'static, EntryOption>
     Ok(EntryOption::MaxRedirect(option))
 }
 
-fn option_retry(reader: &mut Reader) -> ParseResult<'static, EntryOption> {
+fn option_path_as_is(reader: &mut Reader) -> ParseResult<'static, EntryOption> {
     let line_terminators = optional_line_terminators(reader)?;
     let space0 = zero_or_more_spaces(reader)?;
-    try_literal("retry", reader)?;
+    try_literal("path-as-is", reader)?;
     let space1 = zero_or_more_spaces(reader)?;
     try_literal(":", reader)?;
     let space2 = zero_or_more_spaces(reader)?;
     let value = nonrecover(boolean, reader)?;
     let line_terminator0 = line_terminator(reader)?;
 
-    let option = RetryOption {
+    let option = PathAsIsOption {
         line_terminators,
         space0,
         space1,
@@ -550,9 +551,83 @@ fn option_retry(reader: &mut Reader) -> ParseResult<'static, EntryOption> {
         line_terminator0,
     };
 
+    Ok(EntryOption::PathAsIs(option))
+}
+
+fn option_proxy(reader: &mut Reader) -> ParseResult<'static, EntryOption> {
+    let line_terminators = optional_line_terminators(reader)?;
+    let space0 = zero_or_more_spaces(reader)?;
+    try_literal("proxy", reader)?;
+    let space1 = zero_or_more_spaces(reader)?;
+    try_literal(":", reader)?;
+    let space2 = zero_or_more_spaces(reader)?;
+    let value = proxy(reader)?;
+    let line_terminator0 = line_terminator(reader)?;
+    let option = ProxyOption {
+        line_terminators,
+        space0,
+        space1,
+        space2,
+        value,
+        line_terminator0,
+    };
+    Ok(EntryOption::Proxy(option))
+}
+
+fn proxy(reader: &mut Reader) -> ParseResult<'static, String> {
+    let start = reader.state.clone();
+    let name = reader.read_while(|c| c.is_alphanumeric() || *c == ':');
+    if name.is_empty() {
+        return Err(Error {
+            pos: start.pos,
+            recoverable: false,
+            inner: ParseError::Expecting {
+                value: "proxy name".to_string(),
+            },
+        });
+    }
+    Ok(name)
+}
+
+fn option_retry(reader: &mut Reader) -> ParseResult<'static, EntryOption> {
+    let line_terminators = optional_line_terminators(reader)?;
+    let space0 = zero_or_more_spaces(reader)?;
+    try_literal("retry", reader)?;
+    let space1 = zero_or_more_spaces(reader)?;
+    try_literal(":", reader)?;
+    let space2 = zero_or_more_spaces(reader)?;
+    let value = retry(reader)?;
+    let line_terminator0 = line_terminator(reader)?;
+    let option = RetryOption {
+        line_terminators,
+        space0,
+        space1,
+        space2,
+        value,
+        line_terminator0,
+    };
     Ok(EntryOption::Retry(option))
 }
 
+fn retry(reader: &mut Reader) -> ParseResult<Retry> {
+    let pos = reader.state.pos.clone();
+    let value = nonrecover(integer, reader)?;
+    if value == -1 {
+        Ok(Retry::Infinite)
+    } else if value == 0 {
+        Ok(Retry::None)
+    } else if value > 0 {
+        Ok(Retry::Finite(value as usize))
+    } else {
+        Err(Error {
+            pos,
+            recoverable: false,
+            inner: ParseError::Expecting {
+                value: "Expecting a retry value".to_string(),
+            },
+        })
+    }
+}
 fn option_retry_interval(reader: &mut Reader) -> ParseResult<'static, EntryOption> {
     let line_terminators = optional_line_terminators(reader)?;
     let space0 = zero_or_more_spaces(reader)?;
@@ -571,34 +646,9 @@ fn option_retry_interval(reader: &mut Reader) -> ParseResult<'static, EntryOptio
         value,
         line_terminator0,
     };
-
     Ok(EntryOption::RetryInterval(option))
 }
 
-fn option_retry_max_count(reader: &mut Reader) -> ParseResult<'static, EntryOption> {
-    let line_terminators = optional_line_terminators(reader)?;
-    let space0 = zero_or_more_spaces(reader)?;
-    try_literal("retry-max-count", reader)?;
-    let space1 = zero_or_more_spaces(reader)?;
-    try_literal(":", reader)?;
-    let space2 = zero_or_more_spaces(reader)?;
-    let value = nonrecover(natural, reader)?;
-    let line_terminator0 = line_terminator(reader)?;
-
-    // FIXME: try to not unwrap redirect value
-    // and returns an error if not possible
-    let option = RetryMaxCountOption {
-        line_terminators,
-        space0,
-        space1,
-        space2,
-        value: usize::try_from(value).unwrap(),
-        line_terminator0,
-    };
-
-    Ok(EntryOption::RetryMaxCount(option))
-}
-
 fn option_variable(reader: &mut Reader) -> ParseResult<'static, EntryOption> {
     let line_terminators = optional_line_terminators(reader)?;
     let space0 = zero_or_more_spaces(reader)?;
