@@ -84,7 +84,7 @@ impl Tokenizable for Request {
                 .collect(),
         );
         tokens.append(&mut self.space0.tokenize());
-        tokens.push(Token::Method(self.method.to_string()));
+        tokens.append(&mut self.method.tokenize());
         tokens.append(&mut self.space1.tokenize());
         tokens.append(&mut self.url.tokenize());
         tokens.append(&mut self.line_terminator0.tokenize());
@@ -97,6 +97,12 @@ impl Tokenizable for Request {
     }
 }
 
+impl Tokenizable for Method {
+    fn tokenize(&self) -> Vec<Token> {
+        vec![Token::Method(self.to_string())]
+    }
+}
+
 impl Tokenizable for Response {
     fn tokenize(&self) -> Vec<Token> {
         let mut tokens: Vec<Token> = vec![];
@@ -857,9 +863,10 @@ impl Tokenizable for EntryOption {
             EntryOption::Insecure(option) => option.tokenize(),
             EntryOption::FollowLocation(option) => option.tokenize(),
             EntryOption::MaxRedirect(option) => option.tokenize(),
+            EntryOption::PathAsIs(option) => option.tokenize(),
+            EntryOption::Proxy(option) => option.tokenize(),
             EntryOption::Retry(option) => option.tokenize(),
             EntryOption::RetryInterval(option) => option.tokenize(),
-            EntryOption::RetryMaxCount(option) => option.tokenize(),
             EntryOption::Variable(option) => option.tokenize(),
             EntryOption::Verbose(option) => option.tokenize(),
             EntryOption::VeryVerbose(option) => option.tokenize(),
@@ -1014,6 +1021,48 @@ impl Tokenizable for MaxRedirectOption {
     }
 }
 
+impl Tokenizable for PathAsIsOption {
+    fn tokenize(&self) -> Vec<Token> {
+        let mut tokens: Vec<Token> = vec![];
+        tokens.append(
+            &mut self
+                .line_terminators
+                .iter()
+                .flat_map(|e| e.tokenize())
+                .collect(),
+        );
+        tokens.append(&mut self.space0.tokenize());
+        tokens.push(Token::String("path-as-is".to_string()));
+        tokens.append(&mut self.space1.tokenize());
+        tokens.push(Token::Colon(String::from(":")));
+        tokens.append(&mut self.space2.tokenize());
+        tokens.push(Token::Boolean(self.value.to_string()));
+        tokens.append(&mut self.line_terminator0.tokenize());
+        tokens
+    }
+}
+
+impl Tokenizable for ProxyOption {
+    fn tokenize(&self) -> Vec<Token> {
+        let mut tokens: Vec<Token> = vec![];
+        tokens.append(
+            &mut self
+                .line_terminators
+                .iter()
+                .flat_map(|e| e.tokenize())
+                .collect(),
+        );
+        tokens.append(&mut self.space0.tokenize());
+        tokens.push(Token::String("proxy".to_string()));
+        tokens.append(&mut self.space1.tokenize());
+        tokens.push(Token::Colon(String::from(":")));
+        tokens.append(&mut self.space2.tokenize());
+        tokens.push(Token::String(self.value.clone()));
+        tokens.append(&mut self.line_terminator0.tokenize());
+        tokens
+    }
+}
+
 impl Tokenizable for RetryOption {
     fn tokenize(&self) -> Vec<Token> {
         let mut tokens: Vec<Token> = vec![];
@@ -1025,16 +1074,28 @@ impl Tokenizable for RetryOption {
                 .collect(),
         );
         tokens.append(&mut self.space0.tokenize());
-        tokens.push(Token::String("retry".to_string()));
-        tokens.append(&mut self.space1.tokenize());
-        tokens.push(Token::Colon(String::from(":")));
-        tokens.append(&mut self.space2.tokenize());
-        tokens.push(Token::Boolean(self.value.to_string()));
+        if !matches!(self.value, Retry::None) {
+            tokens.push(Token::String("retry".to_string()));
+            tokens.append(&mut self.space1.tokenize());
+            tokens.push(Token::Colon(String::from(":")));
+            tokens.append(&mut self.space2.tokenize());
+            tokens.append(&mut self.value.tokenize());
+        }
         tokens.append(&mut self.line_terminator0.tokenize());
         tokens
     }
 }
 
+impl Tokenizable for Retry {
+    fn tokenize(&self) -> Vec<Token> {
+        match self {
+            Retry::None => vec![Token::Number("0".to_string())],
+            Retry::Finite(n) => vec![Token::Number(n.to_string())],
+            Retry::Infinite => vec![Token::Number("-1".to_string())],
+        }
+    }
+}
+
 impl Tokenizable for RetryIntervalOption {
     fn tokenize(&self) -> Vec<Token> {
         let mut tokens: Vec<Token> = vec![];
@@ -1056,27 +1117,6 @@ impl Tokenizable for RetryIntervalOption {
     }
 }
 
-impl Tokenizable for RetryMaxCountOption {
-    fn tokenize(&self) -> Vec<Token> {
-        let mut tokens: Vec<Token> = vec![];
-        tokens.append(
-            &mut self
-                .line_terminators
-                .iter()
-                .flat_map(|e| e.tokenize())
-                .collect(),
-        );
-        tokens.append(&mut self.space0.tokenize());
-        tokens.push(Token::String("retry-max-count".to_string()));
-        tokens.append(&mut self.space1.tokenize());
-        tokens.push(Token::Colon(String::from(":")));
-        tokens.append(&mut self.space2.tokenize());
-        tokens.push(Token::Number(self.value.to_string()));
-        tokens.append(&mut self.line_terminator0.tokenize());
-        tokens
-    }
-}
-
 impl Tokenizable for VariableOption {
     fn tokenize(&self) -> Vec<Token> {
         let mut tokens: Vec<Token> = vec![];
@@ -1169,6 +1209,12 @@ impl Tokenizable for Filter {
             FilterValue::Count => vec![Token::FilterType(String::from("count"))],
             FilterValue::DaysAfterNow => vec![Token::FilterType(String::from("daysAfterNow"))],
             FilterValue::DaysBeforeNow => vec![Token::FilterType(String::from("daysBeforeNow"))],
+            FilterValue::Decode { space0, encoding } => {
+                let mut tokens: Vec<Token> = vec![Token::FilterType(String::from("decode"))];
+                tokens.append(&mut space0.tokenize());
+                tokens.append(&mut encoding.tokenize());
+                tokens
+            }
             FilterValue::Format { space0, fmt } => {
                 let mut tokens: Vec<Token> = vec![Token::FilterType(String::from("format"))];
                 tokens.append(&mut space0.tokenize());
@@ -1219,6 +1265,12 @@ impl Tokenizable for Filter {
                 tokens
             }
             FilterValue::ToInt => vec![Token::FilterType(String::from("toInt"))],
+            FilterValue::XPath { space0, expr } => {
+                let mut tokens: Vec<Token> = vec![Token::FilterType(String::from("xpath"))];
+                tokens.append(&mut space0.tokenize());
+                tokens.append(&mut expr.tokenize());
+                tokens
+            }
         }
     }
 }
