@@ -15,9 +15,9 @@
  * limitations under the License.
  *
  */
+pub use rules::{check_hurl_file, lint_hurl_file};
 
-pub use self::core::{Error, Lintable, LinterError};
-
+pub use self::core::{Error, LinterError};
 mod core;
 mod error;
 mod rules;
