@@ -176,12 +176,12 @@ fn lint_section_value(section_value: &SectionValue) -> SectionValue {
 fn section_value_index(section_value: SectionValue) -> u32 {
     match section_value {
         // Request sections
-        SectionValue::Options(_) => 0,
-        SectionValue::QueryParams(_) => 1,
-        SectionValue::BasicAuth(_) => 2,
-        SectionValue::FormParams(_) => 3,
-        SectionValue::MultipartFormData(_) => 4,
-        SectionValue::Cookies(_) => 5,
+        SectionValue::QueryParams(_) => 0,
+        SectionValue::BasicAuth(_) => 1,
+        SectionValue::FormParams(_) => 2,
+        SectionValue::MultipartFormData(_) => 3,
+        SectionValue::Cookies(_) => 4,
+        SectionValue::Options(_) => 5,
         // Response sections
         SectionValue::Captures(_) => 0,
         SectionValue::Asserts(_) => 1,
@@ -444,11 +444,12 @@ fn lint_graphql(graphql: &GraphQl) -> GraphQl {
     let space = empty_whitespace();
     let newline = graphql.newline.clone();
     let value = lint_template(&graphql.value);
+    let variables = graphql.variables.clone();
     GraphQl {
         space,
         newline,
         value,
-        variables: None,
+        variables,
     }
 }
 
@@ -483,7 +484,7 @@ fn lint_bytes(bytes: &Bytes) -> Bytes {
 
 fn lint_base64(base64: &Base64) -> Base64 {
     Base64 {
-        space0: one_whitespace(),
+        space0: empty_whitespace(),
         value: base64.value.clone(),
         encoded: base64.encoded.clone(),
         space1: empty_whitespace(),
@@ -492,7 +493,7 @@ fn lint_base64(base64: &Base64) -> Base64 {
 
 fn lint_hex(hex: &Hex) -> Hex {
     Hex {
-        space0: one_whitespace(),
+        space0: empty_whitespace(),
         value: hex.value.clone(),
         encoded: hex.encoded.clone(),
         space1: empty_whitespace(),
@@ -501,7 +502,7 @@ fn lint_hex(hex: &Hex) -> Hex {
 
 fn lint_file(file: &File) -> File {
     File {
-        space0: one_whitespace(),
+        space0: empty_whitespace(),
         filename: Filename {
             value: file.filename.value.clone(),
             source_info: SourceInfo::new(0, 0, 0, 0),
